/**
 * ダイアログ
 */
define([
  "dojo/_base/declare",
  "dojo/dom-attr",
  "dojo/dom-construct",
  "dojo/dom-style",
  "dijit/ConfirmDialog",
], function(declare, domAttr, domConstruct, domStyle, ConfirmDialog) {
  return declare(null, {
    constructor: function(initValue) {
      // ダイアログ名
      this.name = initValue.name;
      // ダイアログID
      this.dialogId = this.name + "Dialog";
      // ダイアログタイトル
      this.title = initValue.title;
      // ダイアログサイズ設定
      this.size = initValue.size;
      // キャンセルボタン表示設定
      this.displayCancelButton = initValue.displayCancelButton;
      // 内容部のID
      this.contentId = this.name + "DialogContent";
      // ダイアログリポジトリキー設定
      this.repositoryKeys = initValue.repositoryKeys;
      // ダイアログ初期化
      this.initDialog();
      // ウィジェット生成
      this.initWidgets();
      // イベント設定
      this.setEvent();
    },

    // ダイアログ初期化処理
    initDialog: function() {
      // ダイアログの div タグ生成
      this.dialogBase = domConstruct.create("div", {
        'id': this.dialogId
      }, document.body);
      // ダイアログ内容部の div タグ生成
      this.createContentBase();
  
      this.dialog = new ConfirmDialog({
        title: this.title,
        style: this.getDialogSize()
      }, this.dialogId);
      this.dialog.okButton.set("label", wagbyDesigner.jfcRes.LABEL_BUTTON_OK);
      this.dialog.cancelButton.set("label", wagbyDesigner.jfcRes.LABEL_BUTTON_CANCEL);
      domStyle.set(this.dialog.actionBarNode, "textAlign", "right");
      domStyle.set(this.dialog.actionBarNode, "paddingRight", "10px");
      if (!this.displayCancelButton) {
        domStyle.set(this.dialog.cancelButton.domNode, "display", "none");
      }
      // 継承クラスでダイアログ表示内容を設定
      this.setContent();
    },

    setContent: function() {
      if (!this.content) {
        return;
      }
      var that = this;
      this.content.on("Load", function() {
        that.onDialogContentLoaded();
      });
    },

    onDialogContentLoaded: function() {
      this.setScreenResource();
    },

    setScreenResource: function() {
      wagbyDesigner.setScreenResources(this.contentId);
    },

    createContentBase: function() {
      var style = this.getContentSize() + " overflow-y: auto;";
      this.contentFrame = domConstruct.create("div", {style: style}, this.dialogBase);
      domConstruct.create("div", {id: this.contentId }, this.contentFrame);
    },

    initWidgets: function() {
      this.widgets = {};
      for (var key in this.repositoryKeys) {
        this.widgets[key] = this.createWidget(key);
      }
    },

    setEvent: function() {
      var that = this;
      this.dialog.okButton.on("click", function() {
        that.dialog.hide();
      });
      // ダイアログ非表示時の処理
      this.dialog.on("Hide", function() {
        that.hide();
      });
    },

    getId: function() {
      return this.obj.getId();
    },

    getName: function() {
      return "";
    },

    getRepositoryItem: function(key) {
      if (!this.repositoryItems) {
        return null;
      }
      return this.repositoryItems[key];
    },

    setRepositoryItems: function(repositoryItems) {
      this.repositoryItems = repositoryItems;
      for (var key in this.repositoryKeys) {
        if (this.repositoryItems[key]) {
          this.widgets[key].setValue(this.repositoryItems[key].value);
          this.widgets[key].setReadOnly(wagbyDesigner.activeModel.isLocked());
        } else {
//console.log("In Dialog repositoryItems key:["+key+"] NOT exists !");
        }
      }
    },

    getTitle: function() {
      this.dialog.get("title");
    },

    setDialogTitle: function() {
      // ダイアログのタイトルに項目名を表示する
      this.dialog.set("title", this.getTitle());
    },

    show: function(obj) {
      if (obj) {
        this.obj = obj;
        this.setRepositoryItems(obj.repositoryItems);
      }
      var that = this;
      this.dialog.show().then(function() {
        that.onDialogShow();
      });
      this.showWidgets();
    },

    onDialogShow: function() {
    },

    showWidgets: function() {
      for (var key in this.repositoryKeys) {
        this.widgets[key].show();
      }
    },

    hide: function() {
    },

    getDialogSize: function() {
      return "width: " + this.size.width + "px; height: " + this.size.height + "px;";
    },

    getContentSize: function() {
      // 内容部の横幅はダイアログの指定サイズから20px、縦は80px差し引く
      return "width: " + (this.size.width - 20) + "px; height: " + (this.size.height - 80) + "px;";
    },

    resizeDialog: function(size) {
      if (!size) {
        return;
      }
      if (size.height) {
        this.size.height = size.height;
      }
      if (size.width) {
        this.size.width = size.width;
      }
      this.dialog.set("style", this.getDialogSize());
      domAttr.set(this.contentFrame, "style", this.getContentSize());
    },

  });
});
